@@ -97,19 +97,6 @@ def reconcile(hub, high, disabled_reqs=None):
                         hinges = find_sls_ids(pname, high)
                     else:
                         hinges.append((pname, pstate))
-                    if "." in pstate:
-                        errors.append(
-                            "Invalid requisite in {}: {} for "
-                            "{}, in SLS '{}'. Requisites must "
-                            "not contain dots, did you mean '{}'?".format(
-                                rkey,
-                                pstate,
-                                pname,
-                                body["__sls__"],
-                                pstate[: pstate.find(".")],
-                            )
-                        )
-                        pstate = pstate.split(".")[0]
                     for tup in hinges:
                         name, _state = tup
                         if key == "use_in":
@@ -171,8 +158,8 @@ def reconcile(hub, high, disabled_reqs=None):
                             extend[name] = {}
                         if _state not in extend[name]:
                             extend[name][_state] = []
-                        extend[name]["__env__"] = body["__env__"]
-                        extend[name]["__sls__"] = body["__sls__"]
+                        extend[name]["__env__"] = body.get("__env__", "base")
+                        extend[name]["__sls__"] = body.get("__sls__", "base")
                         for ind in range(len(extend[name][_state])):
                             if next(iter(extend[name][_state][ind])) == rkey:
                                 # Extending again
