@@ -12,12 +12,15 @@ async def sls(hub) -> int:
     Execute the cli routine to run states
     """
     sls_sources = list(hub.OPT.idem.sls_sources)
+    param_sources = list(hub.OPT.idem.param_sources)
     if hub.OPT.idem.tree:
         tree = f"file://{hub.OPT.idem.tree}"
+        hub.log.debug(f"Added tree to sls and param sources: {tree}")
         sls_sources.append(tree)
+        param_sources.append(tree)
     src = hub.idem.sls_source.init.get_refs(sources=sls_sources, refs=hub.OPT.idem.sls)
     param = hub.idem.sls_source.param.get_refs(
-        sources=hub.OPT.idem.param_sources, refs=hub.OPT.idem.params
+        sources=param_sources, refs=hub.OPT.idem.params
     )
     name = hub.idem.RUN_NAME
     cache_dir = hub.OPT.idem.cache_dir
@@ -32,6 +35,20 @@ async def sls(hub) -> int:
         acct_key=hub.OPT.acct.acct_key,
         serial_plugin=hub.OPT.idem.esm_serial_plugin,
     )
+
+    # Prepare the config dir as a backup sls source
+    if hub.OPT.idem.config:
+        config_dir = (
+            f"file://{pathlib.Path(hub.OPT.idem.config).parent.resolve().absolute()}"
+        )
+
+        # Always use the config dir as a backup sls source
+        hub.log.debug(f"Using config dir as sls source: {config_dir}")
+        src["sls_sources"].append(config_dir)
+        hub.log.debug(f"Using config dir as param source: {config_dir}")
+        param["param_sources"].append(config_dir)
+
+    # Run idem!
     try:
         async with context_manager as state:
             await hub.idem.state.apply(
@@ -81,6 +98,11 @@ async def sls(hub) -> int:
                         managed_state=state,
                     ),
                 )
+            else:
+                # FINISHED event is triggered by the reconciliation.
+                # Triggering the FINISHED event here since reconciliation is
+                # skipped in 'test' mode.
+                hub.idem.state.update_status(name, hub.idem.state.Status.FINISHED)
     except Exception as e:
         display = hub.output.nested.display(str(e))
         print(display)
@@ -129,15 +151,21 @@ async def exec_(hub) -> int:
 
 async def desc(hub) -> int:
     state_path = hub.OPT.idem.desc_glob
-    ret = await hub.idem.describe.run(
-        state_path,
-        hub.OPT.acct.acct_file,
-        hub.OPT.acct.acct_key,
-        hub.OPT.idem.acct_profile,
-        progress=hub.OPT.idem.progress,
-        hard_fail=hub.OPT.idem.hard_fail,
-        search_path=hub.OPT.idem.filter,
-    )
+    try:
+        ret = await hub.idem.describe.run(
+            state_path,
+            hub.OPT.acct.acct_file,
+            hub.OPT.acct.acct_key,
+            hub.OPT.idem.acct_profile,
+            progress=hub.OPT.idem.progress,
+            hard_fail=hub.OPT.idem.hard_fail,
+            search_path=hub.OPT.idem.filter,
+        )
+    except Exception as e:
+        display = hub.output.nested.display(str(e))
+        print(display)
+        # Return a non-zero error code
+        return 1
 
     output = hub.OPT.rend.output or "yaml"
     display = hub.output[output].display(ret)
@@ -162,7 +190,6 @@ async def validate(hub) -> int:
         subs=["states"],
         cache_dir=hub.OPT.idem.cache_dir,
         sls=src["sls"],
-        target=hub.OPT.idem.target,
         test=hub.OPT.idem.test,
         invert_state=hub.OPT.idem.invert,
         acct_file=hub.OPT.acct.acct_file,
