@@ -1,6 +1,5 @@
 import asyncio
 import re
-import warnings
 from typing import Any
 from typing import Dict
 
@@ -36,11 +35,26 @@ async def run(
             hub.states, desc_glob, acct_file, acct_key, acct_profile
         )
     ]
+
+    if len(coros) == 0:
+        # The current approach is to recurse through all loaded resources types.
+        # If it reaches here, it should have gone through all possible resource types when looking up
+        # Do not fail but instead log it, do not return from here as there might be 'auto_state' to process
+        hub.log.warning(
+            f"Cannot find anything to describe for resource type(s) '{desc_glob}'"
+        )
+
+    # This is going through dynamically generated states for exec modules
+    # implementing __contracts__ = ["auto_state"]
     async for coro in hub.idem.describe.recurse(
         hub.exec, desc_glob, acct_file, acct_key, acct_profile
     ):
         coros.append(coro)
 
+    if len(coros) == 0:
+        # If there is none to process including 'auto_state', there is no progress to show. Return empty result
+        return result
+
     # Create the progress bar
     progress_bar = hub.tool.progress.init.create(coros)
 
@@ -125,28 +139,7 @@ async def recurse(
 
                     coro = _async_desc()
                 yield hub.pop.Loop.create_task(coro)
-
-    if hasattr(mod, "_funcs") and "describe" in mod._funcs:
-        # TODO Raise an error here instead of a warning
-        warnings.warn(
-            f"Running 'describe' without implementing the `resource` contract for {mod} is deprecated.\n"
-            "Implement the resource contract for this mod for it to continue functioning in future releases.\n"
-            "__contracts__ = ['resource']",
-            DeprecationWarning,
-        )
-        if re.fullmatch(glob, ref):
-            ctx = await hub.idem.acct.ctx(
-                path=ref,
-                acct_file=acct_file,
-                acct_key=acct_key,
-                acct_profile=acct_profile,
-            )
-            if isinstance(mod.describe, pop.contract.ContractedAsync):
-                coro = mod.describe(ctx)
-            else:
-
-                async def _async_desc():
-                    return mod.describe(ctx)
-
-                coro = _async_desc()
-            yield hub.pop.Loop.create_task(coro)
+    elif (
+        hasattr(mod, "_funcs") and "describe" in mod._funcs and re.fullmatch(glob, ref)
+    ):
+        raise ValueError(f"Implement the resource contract for '{ref}'.")
