@@ -1,23 +1,25 @@
-import warnings
 from typing import Any
 from typing import Dict
 from typing import Tuple
 
 import pop.hub
 
-__func_alias__ = {"ctx_": "ctx"}
-
 
 async def run(
     hub,
     path: str,
     args: Tuple[Any],
     kwargs: Dict[str, Any],
+    *,
     acct_file: str = None,
     acct_key: str = None,
     acct_blob: bytes = None,
-    acct_profile: str = "default",
+    acct_profile: str = None,
+    acct_data: Dict[str, Any] = None,
 ):
+    if acct_profile is None:
+        acct_profile = hub.acct.DEFAULT
+
     args = [a for a in args]
 
     if not path.startswith("exec."):
@@ -36,6 +38,7 @@ async def run(
             acct_key=acct_key,
             acct_profile=acct_profile,
             acct_blob=acct_blob,
+            acct_data=acct_data,
         )
         args.insert(0, ctx)
 
@@ -57,8 +60,3 @@ async def single(hub, path: str, *args, **kwargs):
         acct_profile=acct_profile,
     )
     return ret
-
-
-async def ctx_(hub, *args, **kwargs):
-    warnings.warn("This function has moved to 'hub.idem.acct.ctx'", DeprecationWarning)
-    return await hub.idem.acct.ctx(*args, **kwargs)
