@@ -5,19 +5,21 @@
 # includes to drive to highdata
 # Then we can start to fill out renderers while at the same time
 # deepening the compiler
-import pathlib
 import sys
 
 
 def __init__(hub):
+    hub.idem._omit_class = False
     hub.pop.sub.load_subdirs(hub.idem, recurse=True)
     hub.idem.RUNS = {}
     hub.pop.sub.add(dyne_name="log")
     hub.pop.sub.add(dyne_name="acct")
     hub.pop.sub.add(dyne_name="rend")
+    hub.pop.sub.add(dyne_name="group")
     hub.pop.sub.add(dyne_name="output")
     hub.pop.sub.add(dyne_name="evbus")
     hub.pop.sub.add(dyne_name="reconcile")
+    hub.pop.sub.add(dyne_name="source")
     hub.pop.sub.load_subdirs(hub.reconcile, recurse=True)
     hub.pop.sub.add(dyne_name="tool")
     hub.pop.sub.load_subdirs(hub.tool, recurse=True)
@@ -26,6 +28,7 @@ def __init__(hub):
     hub.pop.sub.load_subdirs(hub.exec, recurse=True)
     hub.pop.sub.add(dyne_name="states")
     hub.pop.sub.load_subdirs(hub.states, recurse=True)
+    hub.pop.sub.add(dyne_name="tree", omit_class=False)
     hub.idem.RMAP = hub.idem.req.init.define()
     hub.idem.RUN_NAME = "cli"
 
@@ -34,7 +37,7 @@ def cli(hub):
     """
     Execute a single idem run from the cli
     """
-    hub.pop.config.load(["idem", "acct", "rend", "evbus"], cli="idem")
+    hub.pop.config.load(["idem", "acct", "rend", "evbus", "pop_tree"], cli="idem")
     # Initialize the async loop for the entire project
     hub.pop.loop.create()
     # Start the main program within the async loop
@@ -49,6 +52,8 @@ async def cli_apply(hub) -> int:
     if hub.SUBPARSER in ("encrypt", "decrypt"):
         # Break early for acct commands
         return await hub.acct.init.cli_apply()
+    elif hub.SUBPARSER == "doc":
+        return await hub.idem.cli.doc()
 
     # Initialize the broker queue for evbus
     await hub.evbus.broker.init()
@@ -57,6 +62,8 @@ async def cli_apply(hub) -> int:
     hub.evbus.SERIAL_PLUGIN = hub.OPT.evbus.serial_plugin
     # Use the run name as a routing key for exec modules
     hub.idem.RUN_NAME = hub.OPT.idem.run_name
+    # Keep the local ESM cache file if explicitly configured to do so
+    hub.idem.managed.KEEP_CACHE_FILE = hub.OPT.idem.esm_keep_cache
 
     # Collect ingress profiles from acct
     ingress_profiles = await hub.evbus.acct.profiles(
@@ -87,48 +94,3 @@ async def cli_apply(hub) -> int:
     finally:
         await hub.evbus.init.stop()
         await listener
-
-
-def get_refs(hub):
-    """
-    Determine where the sls sources are
-    """
-    sls_sources = []
-    slses = []
-    if hub.OPT.idem.tree:
-        tree = f"file://{hub.OPT.idem.tree}"
-        sls_sources.append(tree)
-    for sls in hub.OPT.idem.sls:
-        process_sls(sls_sources, slses, sls)
-
-    sls_sources.extend(hub.OPT.idem.sls_sources)
-
-    return {"sls_sources": sls_sources, "sls": slses}
-
-
-def get_param_refs(hub):
-    """
-    Determine where the param sls sources are
-    """
-    params_file = hub.OPT.idem.params
-    if params_file is None or len(params_file) == 0:
-        return {"param_sources": [], "sls": None}
-
-    param_sources = []
-    slses = []
-    process_sls(param_sources, slses, params_file)
-    param_sources.extend(hub.OPT.idem.param_sources)
-
-    return {"param_sources": param_sources, "sls": slses[0]}
-
-
-def process_sls(sources, slses, sls):
-    path = pathlib.Path(sls)
-    if path.is_file():
-        ref = str(path.stem if path.suffix == ".sls" else path.name)
-        slses.append(ref)
-        implied = f"file://{path.parent}"
-        if implied not in sources:
-            sources.append(implied)
-    else:
-        slses.append(sls)
