@@ -1,4 +1,8 @@
-async def modify(hub, name, chunk):
+from typing import Any
+from typing import Dict
+
+
+async def modify(hub, name: str, chunk: Dict[str, Any]) -> Dict[str, Any]:
     """
     Take the given run name and low chunk, and allow state plugins to modify
     the low chunk
