@@ -58,7 +58,7 @@ def run(
                                 f"Requisite {req} {state}:{name} not found in current run. "
                                 f"For arg_bind requisite, there is an additional step to check in ESM"
                             )
-                            if not req == "arg_bind":
+                            if not req in ["arg_bind", "require"]:
                                 ret[ind]["errors"].append(
                                     f"Requisite {req} {state}:{name} not found"
                                 )
