@@ -11,7 +11,7 @@ def check(
     chunk: Dict[str, Any],
 ) -> Dict[str, Any]:
     """
-    Check to see if the result is True
+    Check to see if there are changes
     """
     if isinstance(condition, bool):
         if bool(reqret["ret"]["changes"]) is condition:
@@ -21,6 +21,6 @@ def check(
         return {}
     return {
         "errors": [
-            f'Changes from {reqret["r_tag"]} is "{reqret["ret"]["result"]}", not "{condition}"'
+            f'Changes from {reqret["r_tag"]} is "{bool(reqret["ret"]["changes"])}", not "{condition}"'
         ]
     }
