@@ -1,12 +1,21 @@
 import copy
+from typing import Any
+from typing import Dict
 
 
-def check(hub, name, ctx, condition, req_ret, chunk):
+def check(
+    hub,
+    name: str,
+    ctx: Dict[str, Any],
+    condition: Any,
+    reqret: Dict[str, Any],
+    chunk: Dict[str, Any],
+) -> Dict[str, Any]:
     """
     If changes are made then run the configured post command
     """
     ret = {}
-    if req_ret["ret"]["changes"]:
+    if reqret["ret"]["changes"]:
         id_ = f"{chunk['__id__']}_listen"
         post_chunk = copy.deepcopy(chunk)
         post_chunk["fun"] = condition
