@@ -25,7 +25,9 @@ def check(
     func = hub.idem.rules.init.get_func(name, r_chunk)
     r_chunk["ctx"] = ctx
     call = hub.idem.tools.format_call(
-        func, r_chunk, expected_extra_kws=hub.idem.rules.init.STATE_INTERNAL_KEYWORDS
+        fun=func,
+        data=r_chunk,
+        expected_extra_kws=hub.idem.rules.init.STATE_INTERNAL_KEYWORDS,
     )
     sret = func(*call["args"], **call["kwargs"])
     cond = sret.get(condition, False)
