@@ -36,13 +36,22 @@ async def start(hub, name, pending_tags: List = None, target: str = None):
     options = {"invert_state": hub.idem.RUNS[name]["invert_state"]}
     low_declaration_ids = [item.get("__id__") for item in low]
 
-    # If there are pending tags re-run only those (reconciliation)
     if pending_tags:
-        # Clear previous running data
+        # During reconciliation only pending tags and their requisites that
+        # are not other resources - such as sleep/script will be re-run.
+        # These resources will be recursively evaluated and added to the low data.
+
+        # Getting rerun_data from all tags
+        rerun_data_map = {}
+        for tag in hub.idem.RUNS[name]["running"]:
+            if hub.idem.RUNS[name]["running"][tag].get("rerun_data"):
+                rerun_data_map[tag.split("_|-")[1]] = hub.idem.RUNS[name]["running"][
+                    tag
+                ].get("rerun_data")
+        # Clearing previous running data.
         hub.idem.RUNS[name]["running"] = {}
-        # Keep low data only for pending tags
         declaration_ids = [tag.split("_|-")[1] for tag in pending_tags]
-        low = [item for item in low if item.get("__id__") in declaration_ids]
+        low = extend_pending_tags(low, declaration_ids, rerun_data_map)
 
     if target:
         # If target is specified - identify all its dependencies
@@ -132,26 +141,36 @@ def gather_target_and_reqs(low, target) -> List[dict]:
     # Target must be declaration id
     # It might resolve to multiple target items if there are
     # multiple resources under the same declaration id
-    gather_(low, [target], low_items)
+    gather_(low, [target], low_items, None)
 
     return low_items
 
 
-def gather_(low: List[Dict], reqs: List[str], low_items: List[Dict]):
-    # Recursively gather low items of target and pre-requisites
-    # Target or any requisite might resolve to multiple resource
-    # items if there are multiple resources under the same declaration id
+def gather_(low: List[Dict], reqs: List[str], low_items: List[Dict], filters: list):
+    """
+    Recursively gather low items of target(s) and their pre-requisites.
+    Any reqs - declaration ID might be resolved to multiple resources,
+    in case there are multiple resources under the same declaration id.
+    :param low:  low data
+    :param reqs: list of declaration ids of requisites ('require')
+    :param low_items: gathered required low items
+    :param filters: filters to filter out low items
+    :return: low data to re-run
+    """
     if not reqs:
         return
     for req in reqs:
         req_items = [item for item in low if item.get("__id__") == req]
+        # Start filtering only after first iteration, where original item(s) are added
+        if low_items and filters:
+            req_items = filter_out_(req_items, filters)
         if len(req_items) < 1:
             continue
         low_items.extend(req_items)
         for req_item in req_items:
             if req_item.get("require"):
                 for required in req_item.get("require"):
-                    gather_(low, list(required.values()), low_items)
+                    gather_(low, list(required.values()), low_items, filters)
 
 
 def extend_low(hub, name, low, low_declaration_ids):
@@ -164,3 +183,48 @@ def extend_low(hub, name, low, low_declaration_ids):
     ]
     low.extend(new_low_items)
     low_declaration_ids += [item.get("__id__") for item in new_low_items]
+
+
+def extend_pending_tags(
+    low, pending_decl_id: list, rerun_data_map: dict = None
+) -> List[dict]:
+    """
+    Gather the states that are corresponding to the pending tags,
+    and its 'require' dependencies that are not resources,
+    Such as time.sleep or data.write or exec.
+    :param low: low data
+    :param pending_decl_id: list of pending declaration ids from reconciliation
+    :return: low items for pending states and their dependencies
+    """
+    low_items = []
+
+    # Pending declaration ids might resolve to multiple items if there are
+    # multiple resources under the same declaration id
+    gather_(low, pending_decl_id, low_items, [{"fun": "absent"}, {"fun": "present"}])
+
+    for key, rerun_data in rerun_data_map.items():
+        for item in low_items:
+            if item.get("__id__") == key:
+                item["rerun_data"] = rerun_data
+
+    return low_items
+
+
+def filter_out_(low_items: List[Dict], filters: List[Dict]) -> List[Dict]:
+    # Filter out required low items that are resources (present/absent)
+    # as those will be retrieved from the ESM. But any others exec/sleep/script
+    # required will be executed
+    if not low_items or not filters:
+        return low_items
+
+    new_low_items = []
+    for item in low_items:
+        match = False
+        for filter in filters:
+            for key, value in filter.items():
+                if item.get(key) == value:
+                    match = True
+        if not match:
+            new_low_items.append(item)
+
+    return new_low_items
