@@ -1,9 +1,17 @@
 import asyncio
+import copy
 from typing import Dict
 
 
 async def runtime(
-    hub, name: str, ctx: Dict, seq: Dict, low: Dict, running: Dict, managed_state: Dict
+    hub,
+    name: str,
+    ctx: Dict,
+    seq: Dict,
+    low: Dict,
+    running: Dict,
+    managed_state: Dict,
+    progress,
 ):
     """
     Execute the runtime in parallel mode
@@ -23,7 +31,8 @@ async def runtime(
         coros.append(
             hub.idem.rules.init.run(
                 name,
-                ctx,
+                # every state run should use unique ctx so that ctx.acct retains correct information during whole state execution.
+                copy.deepcopy(ctx),
                 low,
                 seq[ind],
                 running,
@@ -32,7 +41,7 @@ async def runtime(
             )
         )
         hub.idem.RUNS[name]["run_num"] += 1
+
     for fut in asyncio.as_completed(coros):
         await fut
-    if len(low) <= len(running):
-        return
+        hub.tool.progress.init.update(progress)
