@@ -119,6 +119,7 @@ async def validate(
     subs: List[str],
     cache_dir: str,
     sls: List[str],
+    target: str = None,
     test: bool = False,
     invert_state: bool = False,
     acct_file: str = None,
@@ -300,10 +301,10 @@ async def batch(
     profiles: Dict[str, Any] = None,
     encrypted_profiles: str = None,
     acct_key: str = None,
-    default_acct_profile: str = "default",
+    default_acct_profile: str = None,
     name: str = None,
-    crypto_plugin: str = "fernet",
-    reconcile_plugin: str = "basic",
+    crypto_plugin: str = None,
+    reconcile_plugin: str = None,
     pending_plugin: str = None,
     esm_plugin: str = None,
     esm_profile: str = None,
@@ -327,6 +328,10 @@ async def batch(
     :param esm_profile: The profile for esm
     """
     name = name or f"name_{uuid.uuid4()}"
+    # Get these defaults from config
+    crypto_plugin = crypto_plugin or hub.OPT.acct.crypto_plugin
+    reconcile_plugin = reconcile_plugin or hub.OPT.idem.reconciler
+    default_acct_profile = default_acct_profile or hub.OPT.idem.acct_profile
     runtime = runtime or hub.OPT.idem.runtime
     render = renderer or hub.OPT.idem.render
     test = hub.OPT.idem.test if test is None else test
@@ -397,8 +402,13 @@ async def batch(
                 await hub.reconcile.init.run(
                     plugin=reconcile_plugin,
                     pending_plugin=pending_plugin,
-                    **apply_kwargs,
+                    apply_kwargs=apply_kwargs,
                 )
+            else:
+                # FINISHED event is triggered by the reconciliation.
+                # Triggering the FINISHED event here since reconciliation is
+                # skipped in 'test' mode.
+                hub.idem.state.update_status(name, hub.idem.state.Status.FINISHED)
     except Exception as e:
         display = hub.output.nested.display(str(e))
         print(display)
