@@ -107,11 +107,20 @@ def format_call(
         if name == "hub":
             continue
         elif param.kind.name == "POSITIONAL_OR_KEYWORD":
-            if isinstance(param.default, inspect._empty):
-                args.append(name)
+            if param.default is inspect._empty:
+                if name in enforced_state:
+                    # get it from enforced state before default
+                    kwargs[name] = enforced_state[name]
+                else:
+                    args.append(name)
             else:
-                # get it from enforced state before default
                 kwargs[name] = enforced_state.get(name, param.default)
+                # Validate a boolean value for arguments of type boolean
+                if isinstance(param.default, bool):
+                    if data.get(name) and not isinstance(data.get(name), bool):
+                        raise TypeError(
+                            f"{fun.ref}.{fun.func.__name__} is expecting a boolean value for '{name}' but got '{data.get(name)}'"
+                        )
         elif param.kind.name == "KEYWORD_ONLY":
             # get it from enforced state before default
             kwargs[name] = enforced_state.get(name, param.default)
@@ -132,7 +141,7 @@ def format_call(
             # Do not override enforced_state value with None,
             # unless no value is set
             val = data.pop(key)
-            if val is not None or kwargs[key] == inspect._empty:
+            if val is not None or kwargs[key] is inspect._empty:
                 kwargs[key] = val
         except KeyError:
             # Let's leave the default value in place
@@ -154,10 +163,8 @@ def format_call(
             missing_args.append(arg)
 
     if missing_args:
-        used_args_count = len(ret["args"]) + len(args)
-        args_count = used_args_count + len(missing_args)
-        raise RuntimeError(
-            f"{fun.name} takes at least {args_count} arguments ({used_args_count} given)"
+        raise ValueError(
+            f"{fun.ref}.{fun.func.__name__} is missing required argument(s): {', '.join(missing_args)}"
         )
 
     ret["kwargs"].update(kwargs)
@@ -205,7 +212,6 @@ def format_call(
                     f"{fun.__module__}.{fun.__name__}",
                 ),
             )
-        # raise SaltInvocationError(msg)
     return ret
 
 
