@@ -1,7 +1,16 @@
-from colored import fore
-
 from idem.exec.init import ExecReturn
 
+try:
+    import colorama
+
+    HAS_LIBS = (True,)
+except ImportError as e:
+    HAS_LIBS = False, str(e)
+
+
+def __virtual__(hub):
+    return HAS_LIBS
+
 
 def display(hub, data):
     """
@@ -11,6 +20,6 @@ def display(hub, data):
         return hub.output.nested.display(data)
 
     if not data.result:
-        return fore.RED + str(data.comment)
+        return colorama.Fore.RED + str(data.comment)
     else:
         return hub.output.nested.display(data.ret)
