@@ -5,8 +5,16 @@
 # outputter, this should really just get things like errors added
 from typing import Dict
 
-from colored import attr
-from colored import fg
+try:
+    import colorama
+
+    HAS_LIBS = (True,)
+except ImportError as e:
+    HAS_LIBS = False, str(e)
+
+
+def __virtual__(hub):
+    return HAS_LIBS
 
 
 def display(hub, data):
@@ -15,7 +23,8 @@ def display(hub, data):
     """
     if not isinstance(data, dict):
         return hub.output.nested.display(data)
-    endc = attr(0)
+
+    endc = colorama.Fore.RESET
     strs = []
     fun_count = {}
     for tag in data:
@@ -25,18 +34,18 @@ def display(hub, data):
         id_ = comps[1]
         fun = comps[3]
         result = ret.get("result")
-        comment = ret.get("comment")
+        comment = ret.get("comment", [])
         changes = hub.output.nested.display(ret.get("changes", {}))
         if result is True and changes:
-            tcolor = fg(6)
+            tcolor = colorama.Fore.CYAN
         elif result is True:
-            tcolor = fg(2)
+            tcolor = colorama.Fore.GREEN
         elif result is None:
-            tcolor = fg(11)
+            tcolor = colorama.Fore.LIGHTYELLOW_EX
         elif result is False:
-            tcolor = fg(9)
+            tcolor = colorama.Fore.LIGHTRED_EX
         else:
-            tcolor = fg(0)
+            tcolor = colorama.Fore.RESET
 
         strs.append(f"{tcolor}--------{endc}")
         strs.append(f"{tcolor}      ID: {id_}{endc}")
@@ -55,11 +64,11 @@ def display(hub, data):
             elif ret["changes"]:
                 _increment_count(fun_count, fun, "with_changes")
 
-    strs = strs + format_fun_counts(fun_count)
+    strs = strs + _format_fun_counts(fun_count)
     return "\n".join(strs)
 
 
-def format_fun_counts(fun_map: Dict[str, Dict[str, int]]) -> []:
+def _format_fun_counts(fun_map: Dict[str, Dict[str, int]]) -> []:
     # Format counts for each function
     # Sample output:
     #  present: 1 successful
