@@ -1,4 +1,4 @@
-def sig_is_pending(hub, ret):
+def sig_is_pending(hub, ret: dict, state: str = None):
     """
     Validate the signature of the pending plugin function
     """
