@@ -16,5 +16,10 @@ async def cache(
     """
     data = json.loads(source)
 
-    # Use <source>/<sls file> as the unique sls_ref
-    return f"{source}/{location}", json.dumps(data[location]).encode("utf-8")
+    key = hash(str(source))
+
+    if location in data:
+        zip_loc_data = data[location]
+        data_cache = json.dumps(zip_loc_data).encode("utf-8")
+        # use <source>/<sls file> as the unique sls_ref
+        return f"{key}/{location}", data_cache
