@@ -39,7 +39,9 @@ async def present(hub, ctx, name: str, exec_mod_ref=None, **kwargs):
         ).result
 
     after = await hub.pop.loop.wrap(hub.exec[exec_mod_ref].get, ctx, name, **kwargs)
-    result["changes"] = differ.deep_diff(before.ret, after.ret)
+    result["changes"] = differ.deep_diff(
+        before.ret if before.ret else dict(), after.ret if after.ret else dict()
+    )
     if before.ret and result["changes"]:
         result["comment"] = f"Updated '{exec_mod_ref}:{name}'"
 
