@@ -33,6 +33,8 @@ def _create_state_return(hub, ctx):
     Valid state modules must return a dictionary with these keys
     Validate the output of every state return format.
     """
+    if not ctx.ret:
+        raise ValueError(f"No return from state")
     if (
         "old_state" in ctx.ret
         and "new_state" in ctx.ret
