@@ -8,7 +8,7 @@ def _format_error(ctx, e):
     return {
         "changes": {},
         "comment": [f"{e.__class__.__name__}: {e}"],
-        "name": ctx.kwargs["name"],
+        "name": ctx.kwargs.get("name"),
         "result": False,
     }
 
