@@ -21,7 +21,7 @@ async def sleep(hub, ctx, name, duration: str = None) -> Dict[str, Dict]:
 
     """
     result = dict(
-        comment=f"Sleep-{duration}sec",
+        comment=(),
         old_state={},
         new_state={},
         name=name,
@@ -30,11 +30,15 @@ async def sleep(hub, ctx, name, duration: str = None) -> Dict[str, Dict]:
 
     if duration is None or str(duration) == 0:
         result["result"] = False
-        result["comment"] = "Duration is required."
+        result["comment"] = ("Duration is required.",)
+        return result
+
+    if ctx.get("test", False):
+        result["comment"] = (f"Would sleep for {duration} seconds.",)
         return result
 
     await asyncio.sleep(duration)
 
-    result["comment"] = f"Successfully slept for {duration} seconds."
+    result["comment"] = (f"Successfully slept for {duration} seconds.",)
 
     return result
